@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015 - 2020, Sean Davis <sean@bluesabre.org>
+ * Copyright (C) 2015 - 2024, Sean Davis <sean@bluesabre.org>
  *
  * This program is free software: you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -16,6 +16,7 @@
 
 #define CONFIG_GROUP_DEFAULT            "greeter"
 #define CONFIG_KEY_INDICATORS           "indicators"
+#define CONFIG_KEY_DEFAULT_SESSION      "default-session"
 #define CONFIG_KEY_DEBUGGING            "allow-debugging"
 #define CONFIG_KEY_SCREENSAVER_TIMEOUT  "screensaver-timeout"
 #define CONFIG_KEY_THEME                "theme-name"
@@ -29,7 +30,10 @@
 #define CONFIG_KEY_RGBA                 "xft-rgba"
 #define CONFIG_KEY_HIDE_USER_IMAGE      "hide-user-image"
 #define CONFIG_KEY_DEFAULT_USER_IMAGE   "default-user-image"
+#define CONFIG_KEY_ROUND_USER_IMAGE     "round-user-image"
+#define CONFIG_KEY_HIGHLIGHT_LOGGED_USER "highlight-logged-user"
 #define CONFIG_KEY_KEYBOARD             "keyboard"
+#define CONFIG_KEY_KEYBOARD_LAYOUTS     "keyboard-layouts"
 #define CONFIG_KEY_READER               "reader"
 #define CONFIG_KEY_CLOCK_FORMAT         "clock-format"
 #define CONFIG_KEY_ACTIVE_MONITOR       "active-monitor"
